@@ -1,8 +1,7 @@
 import argparse
 import os
-import shutil
 from .curses_app import download_app, browse_app
-from .themes import get_themes_dir
+from .themes import get_themes_dir, set_theme, get_themedir
 
 
 def scmd_init(args):
@@ -21,7 +20,7 @@ def scmd_init(args):
 
     os.makedirs(themes_dir, exist_ok=True)
 
-    os.system(f'beautifuldiscord --css "{path}"')
+    os.system(f'beaudis --css "{path}"')
 
 
 def scmd_browse(_):
@@ -31,8 +30,7 @@ def scmd_browse(_):
 def scmd_set(args):
     if args.file:
         print("Installing " + args.file + " theme.")
-        shutil.copyfile(args.file, os.path.join(
-            get_themes_dir(), "__current.css"))
+        set_theme(args.file)
     else:
         browse_app()
 
@@ -42,7 +40,9 @@ def scmd_clear(_):
 
 
 def scmd_revert(_):
-    os.system("beautifuldiscord --revert")
+    scmd_clear([])
+    os.remove(get_themedir())
+    os.system("beaudis --revert")
 
 
 def cmd_bdtheme():
